The Genome Taxonomy Network
===========================

The Genome Taxonomy Network, or *GTNet*, is a taxonomic classifier that uses a deep neural network to label DNA
sequences with the `Genome Taxonomy Database taxonomy <https://gtdb.ecogenomic.org/>`_.


.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Getting Started

   installation
   usage

.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Resources

   api_docs
   training
   performance

.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Legal

   legal
